@@ -1,6 +1,6 @@
 #' Creates table of survival probabilities
 #'
-#' \Sexpr[results=rd, stage=render]{lifecycle::badge("experimental")}
+#' \lifecycle{experimental}
 #' Function takes a `survfit` object as an argument, and provides a
 #' formatted summary table of the results
 #'
@@ -19,7 +19,7 @@
 #' is `"{prob} Percentile"` for survival percentiles, and `"Time {time}"` for n-year
 #' survival estimates
 #' @param estimate_fun function to format the Kaplan-Meier estimates. Default
-#' is [style_percent] for survival probabilities and [style_sigfig] for
+#' is [style_percent()] for survival probabilities and [style_sigfig] for
 #' survival times
 #' @param missing text to fill when estimate is not estimable. Default is `"--"`
 #' @param conf.level Confidence level for confidence intervals. Default is 0.95
@@ -27,9 +27,10 @@
 #' Default is `FALSE`.  Does not apply to survival quantile requests
 #' @param y outcome call, e.g. `y = Surv(ttdeath, death)`
 #' @param include Variable to include as stratifying variables.
-#' @param failure DEPRECATED. Use `reverse=` instead.
-#' @param ... Not used
-#' @inheritParams add_global_p.tbl_regression
+#' @param ... For [tbl_survfit.data.frame()]  and [tbl_survfit.survfit()] the arguments
+#' are passed to [tbl_survfit.list()]. They are not used when [tbl_survfit.list()]
+#' is called directly.
+#' @inheritParams add_global_p
 #' @export
 #' @rdname tbl_survfit
 #' @family tbl_survfit tools
@@ -49,7 +50,7 @@
 #' # Pass a data frame
 #' tbl_survfit_ex2 <- tbl_survfit(
 #'   trial,
-#'   y = survival::Surv(ttdeath, death),
+#'   y = Surv(ttdeath, death),
 #'   include = c(trt, grade),
 #'   probs = 0.5,
 #'   label_header = "**Median Survival**"
@@ -97,91 +98,6 @@ tbl_survfit <- function(x, ...) {
   UseMethod("tbl_survfit", x)
 }
 
-#' @export
-#' @rdname tbl_survfit
-tbl_survfit.survfit <- function(x, times = NULL, probs = NULL,
-                                statistic = NULL,
-                                label = NULL, label_header = NULL, estimate_fun = NULL,
-                                missing = NULL, conf.level = 0.95, reverse = FALSE,
-                                quiet = NULL, failure = NULL, ...) {
-  # deprecation notes ----------------------------------------------------------
-  if (!is.null(failure)) {
-    lifecycle::deprecate_warn(
-      "1.3.1", "gtsummary::tbl_survfit(failure = )", "tbl_survfit(reverse = )")
-    reverse <- failure
-    rm(failure)
-  }
-
-  # converting inputs to be compatible with the list method
-  x <- list(x)
-  if (rlang::is_string(label)) label <- expr(everything() ~ !!label) %>% eval()
-
-  # passing all args to the list method of `tbl_survfit()`
-  expr(tbl_survfit.list(!!!as.list(environment()))) %>% eval()
-}
-
-#' @export
-#' @rdname tbl_survfit
-tbl_survfit.data.frame <- function(x, y, times = NULL, probs = NULL,
-                                   statistic = NULL,
-                                   label = NULL, label_header = NULL, estimate_fun = NULL,
-                                   missing = NULL, conf.level = 0.95, reverse = FALSE,
-                                   failure = NULL, include = everything(), quiet = NULL, ...) {
-  include <- dplyr::select(x, {{include}}) %>% names()
-
-  # checking inputs ------------------------------------------------------------
-  # able to construct Surv() object?
-  y <- enexpr(y)
-
-  y_surv <-
-    tryCatch(
-      expr(with(!!x, !!y)) %>% eval(),
-      error = function(e) {
-        paste("There was are error constructing the `Surv()` object from the",
-              "data frame passed in `x=`, and the outcome passed in `y=`.",
-              "All columns in `y=` should appear in `x=`.\n\n") %>%
-          stringr::str_wrap() %>%
-          c(as.character(e)) %>%
-          stop(call. = FALSE)
-      }
-    )
-
-  # Surv object is indeed a of class Surv
-  if (!inherits(y_surv, "Surv")) {
-    paste("Together, the data frame in `x=`, and the survival outcome in `y=`",
-          "must construct `Surv` oject, e.g. `with(trial, Surv(ttdeath, death))`") %>%
-      stringr::str_wrap() %>%
-      stop(call. = FALSE)
-  }
-
-  # getting list of all covariates ---------------------------------------------
-  y_vars <- as.list(y)[-1] %>% map(deparse) %>% unlist()
-  x_vars <- include %>% setdiff(y_vars)
-
-  # construct list of survfits -------------------------------------------------
-  survfit_expr_list <-
-    tryCatch(
-      map(
-        x_vars,
-        function(.x) expr(survival::survfit(!!y ~ !!sym(.x), data = !!x)) %>% eval()
-      ),
-      error = function(e) {
-        paste("There was are error constructing the list `survfit()` objects from the",
-              "data frame passed in `x=`, and the outcome passed in `y=`.") %>%
-          stringr::str_wrap() %>%
-          stop(call. = FALSE)
-      }
-    )
-
-  # passing all args to the list method of `tbl_survfit()` ---------------------
-  tbl_survfit_args <-
-    as.list(environment())[!names(as.list(environment())) %in% c("x", "y", "y_surv", "y_vars",
-                                                                 "x_vars", "survfit_expr_list",
-                                                                 "include")]
-
-  expr(tbl_survfit.list(x = survfit_expr_list, !!!tbl_survfit_args)) %>% eval()
-}
-
 #' @export
 #' @rdname tbl_survfit
 tbl_survfit.list <- function(x, times = NULL, probs = NULL,
@@ -200,7 +116,13 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
   quiet <- quiet %||% get_theme_element("pkgwide-lgl:quiet") %||% FALSE
 
   # input checks ---------------------------------------------------------------
-  assert_package("survival", "tbl_survfit")
+  if (rlang::is_string(label)) {
+    label <- inject(everything() ~ !!label)
+    # lifecycle::deprecate_warn(
+    #   "1.3.6", "gtsummary::tbl_survfit(label=)",
+    #   details = "`label=` argument no longer accepts a single string. Pass formula list.")
+  }
+  assert_package("survival", "tbl_survfit()")
   if (purrr::every(x, ~!inherits(.x, "survfit"))) {
     stop("Argument `x=` must be class 'survfit' created from the `survival::survfit()` function.",
          call. = FALSE)
@@ -242,10 +164,13 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
     )
 
   # apply labels
-  label <- tidyselect_to_list(
-    .data = vctr_2_tibble(unique(meta_data$variable)),
-    x = label, arg_name = "label"
-  )
+  label <-
+    .formula_list_to_named_list(
+      x = label,
+      var_info = meta_data_to_var_info(meta_data),
+      arg_name = "label"
+    )
+
   meta_data <-
     meta_data %>%
     mutate(
@@ -259,7 +184,7 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
 
   # checking that the variable list is unique
   if (quiet == FALSE && !identical(meta_data$variable, unique(meta_data$variable))) {
-    paste("The variable list in `.$meta_data` is not unique.",
+    paste("tbl_survfit: The variable list in `.$meta_data` is not unique.",
           "This could pose a problem with  subsequent `tbl_survfit` calls,",
           "e.g. `tbl_survfit() %>% add_p()`") %>%
       stringr::str_wrap() %>%
@@ -267,7 +192,11 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
   }
 
   # table_header ---------------------------------------------------------------
-  table_body <- map_dfr(meta_data$table_body, ~.x)
+  table_body <-
+    meta_data %>%
+    select(.data$var_label, .data$table_body) %>%
+    unnest(.data$table_body) %>%
+    select(.data$variable, .data$var_label, everything())
   table_header <-
     tibble(column = names(table_body)) %>%
     table_header_fill_missing()
@@ -285,7 +214,7 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
   # applying labels
   lbls <- as.list(unique(meta_data$df_stats[[1]]$col_label)) %>% set_names(unique(meta_data$df_stats[[1]]$col_name))
   results <-
-    expr(modify_header_internal(results, label = !!paste0("**", translate_text("Characteristic"), "**"), !!!lbls)) %>%
+    expr(modify_header(results, label = !!paste0("**", translate_text("Characteristic"), "**"), !!!lbls)) %>%
     eval()
 
   # exporting results ----------------------------------------------------------
@@ -296,6 +225,65 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
   results
 }
 
+#' @export
+#' @rdname tbl_survfit
+tbl_survfit.survfit <- function(x, ...) {
+  # passing all args to the list method of `tbl_survfit()`
+  tbl_survfit.list(list(x), ...)
+}
+
+#' @export
+#' @rdname tbl_survfit
+tbl_survfit.data.frame <- function(x, y, include = everything(), ...) {
+  include <- dplyr::select(x, {{include}}) %>% names()
+
+  # checking inputs ------------------------------------------------------------
+  # able to construct Surv() object?
+  y <- enexpr(y)
+
+  y_surv <-
+    tryCatch(
+      expr(with(!!x, !!y)) %>% eval(),
+      error = function(e) {
+        paste("There was are error constructing the `y = Surv()` object from the",
+              "data frame passed in `x=`, and the outcome passed in `y=`.",
+              "All columns in `y=` should appear in `x=`.\n\n") %>%
+          stringr::str_wrap() %>%
+          c(as.character(e)) %>%
+          stop(call. = FALSE)
+      }
+    )
+
+  # Surv object is indeed a of class Surv
+  if (!inherits(y_surv, "Surv")) {
+    paste("Together, the data frame in `x=`, and the survival outcome in `y=`",
+          "must construct `Surv` oject, e.g. `with(trial, Surv(ttdeath, death))`") %>%
+      stringr::str_wrap() %>%
+      stop(call. = FALSE)
+  }
+
+  # getting list of all covariates ---------------------------------------------
+  y_vars <- inject(all.vars(~!!y))
+  x_vars <- include %>% setdiff(y_vars)
+
+  # construct list of survfits -------------------------------------------------
+  survfit_expr_list <-
+    tryCatch(
+      map(
+        x_vars,
+        function(.x) expr(survival::survfit(!!y ~ !!sym(.x), data = !!x)) %>% eval()
+      ),
+      error = function(e) {
+        paste("There was are error constructing the list `survfit()` objects from the",
+              "data frame passed in `x=`, and the outcome passed in `y=`.") %>%
+          stringr::str_wrap() %>%
+          stop(call. = FALSE)
+      }
+    )
+
+  tbl_survfit.list(x = survfit_expr_list, ...)
+}
+
 # function that uses meta_data and inputs to finish tbl ----------------------
 meta_to_df_stats <- function(meta_data, inputs, estimate_type, estimate_fun,
                              missing, statistic) {
@@ -402,7 +390,7 @@ survfit_time <- function(x, variable, times, label_header, conf.level,
       purrr::pluck(1)
 
     if (identical(quiet, FALSE)) rlang::inform(glue(
-      "Multi-state model detected. Showing probabilities into state '{state}'"))
+      "tbl_survfit: Multi-state model detected. Showing probabilities into state '{state}'"))
 
     tidy <- dplyr::filter(tidy, .data$state == .env$state)
   }
